=============================
Python Lunar
=============================

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: http://opensource.org/licenses/MIT
   :alt: MIT License

.. image:: https://badge.fury.io/py/pylunar.png
    :target: http://badge.fury.io/py/pylunar

.. image:: https://travis-ci.org/mareuter/pylunar.png?branch=master
    :target: https://travis-ci.org/mareuter/pylunar

Information for completing the Astronomical League's Lunar and Lunar II observing programs.


Features
--------

* Offer moon information based off location and date/time.

